import Component from '@glimmer/component';
import { DateTime } from 'luxon';
import { action } from '@ember/object';

/**
 * Shows a formatted piece of text or data.
 *
 * ```html
 * <OxiBase::Formatted @format="timestamp" @value="1617102928" @class="big" @truncate={{true}} />
 * ```
 *
 * @param { string } format - how the value shall be formatted
 * Possible formats:
 * - `certstatus`
 * - `link`
 * - `extlink`
 * - `timestamp`
 * - `text`
 * - `nl2br`
 * - `code`
 * - `asciidata`
 * - `download`
 * - `raw`
 * - `deflist`
 * - `ullist`
 * - `rawlist`
 * - `linklist`
 * - `styled`
 * - `tooltip`
 * @param value - value to be formatted - the data type depends on the format
 * @module component/oxi-base/formatted
 */
export default class OxiFormattedComponent extends Component {
    get format() {
        return (this.args.format || "text");
    }

    get valueStr() {
        return (new String(this.args.value || "")).replace(/\r/gm, "");
    }

    get valueSplitByNewline() {
        return this.valueStr.split(/\n/);
    }

    get timestamp() {
        return (this.args.value > 0
            ? DateTime.fromSeconds(parseInt(this.args.value)).setZone('utc').toFormat('yyyy-MM-dd HH:mm:ss') + ' UTC'
            : '---');
    }

    get styledValue() {
        let m = this.args.value.match(/^(([a-z]+):)?(.*)$/m);
        return {
            style: m[2],
            label: m[3],
        };
    }

    @action
    selectCode(event) {
        let element = event.target;
        if (window.getSelection) {
            const selection = window.getSelection();
            const range = document.createRange();
            range.selectNodeContents(element);
            selection.removeAllRanges();
            selection.addRange(range);
        } else {
            console.warn("Could not select text: Unsupported browser");
        }
    }

}
